import React, { useRef, useImperativeHandle, forwardRef } from "react"

import Drawer from '../Drawer'

import { Toolbar, Tooltip, Typography, Box } from '@material-ui/core'
import { HelpOutline } from "@material-ui/icons"
import { StyledHeader } from "./styles"

import btn_home from '../../assets/buttons/btn_home.svg'
import RoundButton from "../RoundButton"

import pdf1 from '../../assets/documents/versaopdf.pdf'

const Header = (props, ref) => {
  const { help, download, nohome, cover, title } = props
  const drawerref = useRef(Drawer)

  const openDrawer = async (key) => {
    if(!drawerref.current){
        return
    }

    await drawerref.current.openDrawer(key)
    drawerref.current.scrollList()
  }

  useImperativeHandle(ref, () => ({
    openRef: key => {
      openDrawer(key)
    }
  }))

  return (
    <StyledHeader cover={cover}>
      <Toolbar>
        <Drawer ref={drawerref}/>
        {
          nohome?
          null
          :
            <RoundButton tooltip="Início" to="/" type="home" margin={true}/>
        }
        {title ? 
            <Typography variant="body2" id='title'>
              <p className='ml-3 mb-0'>{props.title}</p>
            </Typography>
            : 
            <></>}       
        <div className="endbutton">
          {
            help?
              <RoundButton tooltip="Ajuda" type="help" margin/>
            :
              <RoundButton disabled/>
          }
          {
            download?
              <a href={pdf1} target='_blank'><RoundButton tooltip="Versão pdf" type="download" margin/></a>
            :
              <RoundButton disabled/>
          }
        </div>
      </Toolbar>
    </StyledHeader>
  )
}

export default forwardRef(Header)
