import React, { useState } from 'react'
import { Typography, Box } from '@material-ui/core'
import Reference from '../../components/Reference'
import DefaultPage from '../../components/DefaultPage'

import { StyledContainer, Modal, ModalButton } from './styles'

import sabermais from '../../assets/buttons/sabermais.png'
import fechar from '../../assets/buttons/fechar.svg'

import imagem from '../../assets/imagesNova/p20.png'

import pdf1 from '../../assets/documents/documento_orientador_indicadores_de_desempenho_200210.pdf'
import pdf2 from '../../assets/documents/qualificadores_indicador_CDS.pdf'

export default function () {
  const [effect, setEffect] = useState(false)
  const [ref, setRef] = useState(0)

  const visible = {
    visibility: 'visible'
  }
  const noVisible = {
    visibility: 'collapse'
  }
  const [modal, setModal] = useState(noVisible)

  return (
    <DefaultPage effect={effect} referencia={ref} header footerColor='#18bfc5' replay='/p8' next='/p21'  title3='Quais categorias de indicadores deverão ser observadas para o pagamento por desempenho?'>
      <StyledContainer>
        <Typography variant='body1'>
          <p id='text' className='m-0'>
            São elas:
          </p>
          <Box className='d-flex align-items-center mb-1 mobile'>
            <img src={imagem} alt='' id='imagem' />
            <p id='texto-superior'>
            Indicadores de processo e resultados intermediários das equipes, por exemplo: prevenção e manejo de doenças infecciosas e crônicas;
            <br/>Indicadores de resultados em saúde, por exemplo, saúde materno-infantil;
            <br/>Indicadores globais de APS, como a avaliação da qualidade assistencial e a experiência do paciente.
            </p>

          </Box>
          <p>
          Os indicadores deverão considerar a relevância clínica e epidemiológica, a disponibilidade, simplicidade, o baixo custo de obtenção, a adaptabilidade, a estabilidade, a rastreabilidade e a representatividade. Você deve observar que a Portaria nº 3.222, de 10 de dezembro de 2019, determina as ações estratégicas e os indicadores do ano de 2020, assim como estabelece as ações estratégicas para definição dos indicadores dos anos de 2021 e 2022<Reference num="12" onClick={() => [setRef(12), setEffect(!effect)]} />. 
          </p>
          <p>
          Outro ponto de apoio importante para que o gestor entenda e pratique a nova lógica do financiamento é a Nota Técnica nº 5/2020/DESF/SAPS/MS, que trata dos indicadores de pagamento por desempenho do Programa Previne Brasil. Nela, o gestor encontrará as fichas de qualificação do conjunto de indicadores que compõem o incentivo financeiro de pagamento por desempenho da APS. A nota aponta para a importância da qualificação, do monitoramento e da avaliação dos indicadores selecionados para o pagamento por desempenho<Reference num="13" onClick={() => [setRef(13), setEffect(!effect)]} />. 
          </p>
        </Typography>
        <ModalButton onClick={() => [setModal(visible)]}>
          <img src={sabermais} alt='para saber mais'/>
          <Typography variant='body1'>
          PARA SABER MAIS
          </Typography>
        </ModalButton>
        <Modal style={modal}>
          <Typography className='d-flex botao-saber-mais-modal' variant='body1'>
            <img src={sabermais} alt='para saber mais' id='saber-mais-modal'/>
            <p id='psm-text-modal'>
            PARA SABER MAIS
            </p>
          </Typography>
          <Typography variant='body1' className='text-modal'>
            <p>Clique <a href={pdf1} target='_blank'>aqui</a> e conheça as orientações acerca de como a equipe de saúde da família pode melhorar os indicadores de desempenho.</p>
            <p>Acesse também o <a href={pdf2} target='_blank'>Guia para qualificação dos indicadores da APS</a> referentes à Coleta de Dados Simplificada.</p>
          </Typography>
          <div id='button'>
            <img src={fechar} alt='' id='fechar' onClick={() => setModal(noVisible)} />
          </div>
        </Modal>
      </StyledContainer>
    </DefaultPage>
  )
}
