import React, { useState, useRef, useEffect } from 'react'
import { Typography, Box, useMediaQuery } from '@material-ui/core'
import DefaultPage from '../../components/DefaultPage'
import { StyledContainer, Modal, FundoEscuro } from './styles'
import Reference from '../../components/Reference'

import sabermais from '../../assets/buttons/sabermais.png'

import fechar from '../../assets/buttons/fechar.svg'
import bg from '../../assets/imagesNova/p21A.png'
import bgMobile from '../../assets/imagesNova/p21AMobile.png'
import botao1 from '../../assets/imagesNova/p21B.png'
import botao2 from '../../assets/imagesNova/p21C.png'
import botao3 from '../../assets/imagesNova/p21D.png'
import botao4 from '../../assets/imagesNova/p21E.png'
import botao5 from '../../assets/imagesNova/p21F.png'

import pdf1 from '../../assets/documents/qualificadores_indicador_PEC.pdf'

export default function () {
  const texto1 = <p>Definir o incentivo financeiro do pagamento por desempenho por Município e Distrito Federal.</p>
  const texto2 = <p>Subsidiar a definição de prioridades e o planejamento de ações para melhoria da qualidade da APS.</p>
  const texto3 = <p>Promover o reconhecimento dos resultados alcançados e a efetividade ou necessidade de aperfeiçoamento das estratégias de intervenção.</p>
  const texto4 = <p>Orientar o processo de pagamento por desempenho no âmbito da gestão municipal, assim como entre este e as outras esferas de gestão do SUS.</p>
  const texto5 = <p>Promover a democratização e transparência da gestão da APS e o fortalecimento da participação das pessoas, por meio da publicização de metas e resultados alcançados.</p>
  const textoSaberMais = <p>Sobre a informatização da APS, foi instituído pela Portaria nº 2.983, de 11 de novembro de 2019 (alterando as Portarias de Consolidação nº 5/GM/MS e nº 6/GM/MS, de 28 de setembro de 2017), o <strong>Informatiza APS</strong>. O programa tem por objetivo apoiar a informatização das unidades de saúde e a qualificação dos dados da APS em todo território nacional. E nesse sentido, o investimento na tecnologia da informação vai subsidiar a gestão dos serviços de saúde e a melhoria da clínica.<br />Este Programa faz parte da estratégia de saúde digital do Ministério da Saúde. É importante que você como gestor conheça e acesse a plataforma Conecte SUS, clique <a href='https://www.saude.gov.br/component/tags/tag/conecte-sus' target='_blank'>aqui</a> e conheça o site. Assista aos vídeos abaixo, produzidos pelo CONASEMS: <ul><li><a href='https://www.youtube.com/watch?v=qNRAD9Gg-gM' target='_blank'>Informatiza APS</a></li><li><a href='https://www.youtube.com/watch?v=fCGoe8KP3NA&t=10s' target='_blank'>Parâmetros minimos do Informatiza APS</a></li></ul>Leia também o <a href={pdf1} target='_blank'>Guia para qualificação dos indicadores da APS referente ao Prontuário Eletrônico do Cidadão</a>.</p>

  const [exibirTexto, setTexto] = useState(texto1)
  const [modalGrande, setModalGrande] = useState(1)

  const [ref, setRef] = useState(0)
  const [effect, setEffect] = useState(false)

  const web = useMediaQuery('(min-width: 900px)')

  const visible = {
    visibility: 'visible'
  }
  const noVisible = {
    visibility: 'collapse'
  }
  const [modal, setModal] = useState(noVisible)

  return (
    <>
      {modalGrande === 0 ? <FundoEscuro /> : <></>}
      <DefaultPage header title3='Quais categorias de indicadores deverão ser observadas para o pagamento por desempenho?' referencia={ref} effect={effect} footerColor='#18bfc5' replay='/p8' prev='/p20' next='/p22'>
        <StyledContainer>
          <Typography variant='body1'>
            <p>
          Importante destacar que o monitoramento e a avaliação são ferramentas de transparência que têm por objetivos, dentre outros, analisar o acesso e a qualidade dos serviços prestados, possibilitar a implementação de medidas de correção e/ou aprimoramento das ações e serviços, assim como prestar contas à população sobre o investimento na área da saúde.
            </p>
            <p>
          Conforme apontamentos da Nota Técnica nº 5/2020/DESF/SAPS/MS, o monitoramento dos indicadores e consequente uso das informações buscam<Reference num='13' onClick={() => [setRef(13), setEffect(!effect)]} />:
            </p>
          </Typography>
          <Box className='box'>
            {
              web
                ? <Box className='bg-desktop'>
                  <img src={bg} alt='' />
                </Box>

                : <Box className='bg-mobile'>
                  <img src={bgMobile} alt='' />
                </Box>
            }
            <Box id='botao1' className='botao'>
              <img src={botao1} alt='' onClick={() => [setTexto(texto1), setModal(visible), setModalGrande(0)]} />
            </Box>
            <Box id='botao2' className='botao'>
              <img src={botao2} alt='' onClick={() => [setTexto(texto2), setModal(visible), setModalGrande(0)]} />
            </Box>
            <Box id='botao3' className='botao'>
              <img src={botao3} alt='' onClick={() => [setTexto(texto3), setModal(visible), setModalGrande(0)]} />
            </Box>
            <Box id='botao4' className='botao'>
              <img src={botao4} alt='' onClick={() => [setTexto(texto4), setModal(visible), setModalGrande(0)]} />
            </Box>
            <Box id='botao5' className='botao'>
              <img src={botao5} alt='' onClick={() => [setTexto(texto5), setModal(visible), setModalGrande(0)]} />
            </Box>
          </Box>
          <Typography variant='body1'>
            <p>
          Perceba que se trata do monitoramento e da avaliação como ferramentas de gestão em saúde, que possibilitam não somente o cumprimento de metas, mas também a produção de informação em saúde, com vistas ao aprimoramento do sistema de saúde.
            </p>
          </Typography>
          <Typography className='d-flex botao-saber-mais' variant='body1' onClick={() => [setTexto(textoSaberMais), setModal(visible), setModalGrande(5)]}>
            <img src={sabermais} alt='para saber mais' id='saber-mais' />
            <p id='psm-text'>
          PARA SABER MAIS
            </p>
          </Typography>
        </StyledContainer>
        <Modal style={modal} texto={modalGrande}>
          <Typography className='d-flex botao-saber-mais-modal' variant='body1'>
            <img src={sabermais} alt='para saber mais' id='saber-mais-modal' />
            <p id='psm-text-modal'>
            PARA SABER MAIS
            </p>
          </Typography>
          <Typography variant='body1' id='text-modal'>
            {exibirTexto}
          </Typography>
          <div id='button'>
            <img src={fechar} alt='' id='fechar' onClick={() => [setModal(noVisible), setModalGrande(1)]} />
          </div>
        </Modal>
      </DefaultPage>
    </>
  )
}
